-- Transmog Notification
-- Author: Charlott-Mal'ganis, Rhaeoh-Area52
-- Notifies you when you add new transmog appearances or unlock new item names (via looting BoP items or equipping BoE items).
-- Notifies you when you remove an appearance or item name from your collection.

local lastItem = nil
local newItem = false
local lastEquippedItem = nil
local equipItem = false

local TransmogNotification = CreateFrame("FRAME", "TransmogFrame")
TransmogNotification:RegisterEvent("TRANSMOG_COLLECTION_UPDATED") -- fires when item added/removed in appearances
TransmogNotification:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")
TransmogNotification:RegisterEvent("CHAT_MSG_LOOT")

local function eventHandler(self, event, ...)
	-- BoE items:
	if event == "PLAYER_EQUIPMENT_CHANGED" then
		-- if equipping an item, event PLAYER_EQUIPMENT_CHANGED returns slotID, 1 or nil 
		-- record last equipped item
		if (select(2,...)) == 1 then
			local invSlot = (select(1,...))
			local equippedItemID = GetInventoryItemID("player", invSlot)
			local _, equippedItemLink = GetItemInfo(equippedItemID)
			lastEquippedItem = equippedItemLink
			equipItem = true
		end
	end
	-- BoP items:
	if event == "CHAT_MSG_LOOT" then
		-- when looting an item, CHAT_MSG_LOOT returns a message with item link
		-- record last looted item
		local _,_,dItemID = string.find(..., ".*|Hitem:(%d+):.*")
		local _,dItemLink = GetItemInfo(dItemID);
		lastItem = dItemLink
		newItem = true
	end	
	-- Notifications:
	if event == "TRANSMOG_COLLECTION_UPDATED" then
		latestAppID, latestAppCategory = C_TransmogCollection.GetLatestAppearance()
		if latestAppID ~= nil and newItem == true then
			local sources = C_TransmogCollection.GetAppearanceSources(C_TransmogCollection.GetLatestAppearance())
			for index, value in ipairs(sources) do
				if GetItemInfo(lastItem) == GetItemInfo(select(6, C_TransmogCollection.GetAppearanceSourceInfo(value["sourceID"]))) then
					print("Added ".. lastItem.. " as ".. (select(7, C_TransmogCollection.GetAppearanceSourceInfo(value["sourceID"])))..".")
					newItem = false
				end
			end
		elseif latestAppID ~= nil and equipItem == true then
			local sources = C_TransmogCollection.GetAppearanceSources(C_TransmogCollection.GetLatestAppearance());
			for index, value in ipairs(sources) do
				if GetItemInfo(lastEquippedItem) == GetItemInfo(select(6, C_TransmogCollection.GetAppearanceSourceInfo(value["sourceID"]))) then
					print("Added ".. lastEquippedItem.. " as ".. (select(7, C_TransmogCollection.GetAppearanceSourceInfo(value["sourceID"])))..".")
					equipItem = false
				end
			end
		else
			if event == "TRANSMOG_COLLECTION_UPDATED" and newItem == false then
				print("Removed from collection.")
			end
		end
	end
end

TransmogNotification:SetScript("OnEvent", eventHandler)